@@ -2,7 +2,7 @@
  * (c)LGPL2+
  *
  * LXQt - The Lightweight Desktop Environment
- * http://lxqt.org
+ * https://lxqt.org
  *
  * Copyright (C) 2011  Alec Moskvin <alecm@gmx.com>
  *
@@ -27,6 +27,7 @@
 #include <XdgIcon>
 
 #include "autostartmodel.h"
+#include "autostartutils.h"
 
 AutoStartItemModel::AutoStartItemModel(QObject* parent) :
     QAbstractItemModel(parent),
@@ -37,7 +38,7 @@ AutoStartItemModel::AutoStartItemModel(QObject* parent) :
     QMap<QString,AutostartItem>::iterator iter;
     for (iter = mItemMap.begin(); iter != mItemMap.end(); ++iter)
     {
-        if (!iter.value().file().value("X-LXQt-Module", false).toBool())
+        if (!AutostartUtils::isLXQtModule(iter.value().file()))
         {
             if (showOnlyInLXQt(iter.value().file()))
                 mLXQtItems.append(iter.key());
@@ -56,11 +57,24 @@ AutoStartItemModel::~AutoStartItemModel()
  */
 bool AutoStartItemModel::writeChanges()
 {
-    foreach (AutostartItem item, mItemMap.values())
+    for(AutostartItem& item : mItemMap)
         item.commit();
     return true;
 }
 
+QMap<QString, AutostartItem> AutoStartItemModel::items()
+{
+    QMap<QString, AutostartItem> allItems;
+
+    for(const QString &s : qAsConst(mLXQtItems))
+        allItems[s] = mItemMap.value(s);
+
+    for(const QString &s : qAsConst(mGlobalItems))
+        allItems[s] = mItemMap.value(s);
+
+    return allItems;
+}
+
 /*
  * Creates or replaces an autostart entry
  */
