@@ -2,7 +2,7 @@
  * (c)LGPL2+
  *
  * LXQt - a lightweight, Qt based, desktop toolset
- * http://razor-qt.org, http://lxde.org/
+ * https://lxqt.org/
  *
  * Copyright: 2010-2012 LXQt team
  * Authors:
@@ -62,7 +62,8 @@ BasicSettings::~BasicSettings()
 void BasicSettings::restoreSettings()
 {
     QStringList knownWMs;
-    foreach (const WindowManager &wm, getWindowManagerList(true))
+    const auto wmList = getWindowManagerList(true);
+    for (const WindowManager &wm : wmList)
     {
         knownWMs << wm.command;
     }
