@@ -1,10 +1,10 @@
 /* BEGIN_COMMON_COPYRIGHT_HEADER
  * (c)LGPL2+
  *
- * LxQt - a lightweight, Qt based, desktop toolset
- * http://razor-qt.org, http://lxde.org/
+ * LXQt - a lightweight, Qt based, desktop toolset
+ * https://lxqt.org/
  *
- * Copyright: 2010-2012 LxQt team
+ * Copyright: 2010-2012 LXQt team
  * Authors:
  *   Petr Vanek <petr@scribus.info>
  *
@@ -28,7 +28,7 @@
 #include "environmentpage.h"
 #include "ui_environmentpage.h"
 
-EnvironmentPage::EnvironmentPage(LxQt::Settings *settings, QWidget *parent) :
+EnvironmentPage::EnvironmentPage(LXQt::Settings *settings, QWidget *parent) :
     QWidget(parent),
     m_settings(settings),
     ui(new Ui::EnvironmentPage)
@@ -54,7 +54,8 @@ void EnvironmentPage::restoreSettings()
     m_settings->beginGroup("Environment");
     QString value;
     ui->treeWidget->clear();
-    foreach (const QString& i, m_settings->childKeys())
+    const auto keys = m_settings->childKeys();
+    for (const QString& i : keys)
     {
         value = m_settings->value(i).toString();
         QTreeWidgetItem *item = new QTreeWidgetItem(ui->treeWidget, QStringList() << i << value);
@@ -73,14 +74,38 @@ void EnvironmentPage::restoreSettings()
 
 void EnvironmentPage::save()
 {
+    bool doRestart = false;
+    QMap<QString, QString> oldSettings;
+
     m_settings->beginGroup("Environment");
+
+    /* We erase the Enviroment group and them write the Ui settings. To know if
+       they changed or not we need to save them to memory.
+     */
+    const auto keys = m_settings->childKeys();
+    for (const QString &key : keys)
+        oldSettings[key] = m_settings->value(key, QString()).toString();
     m_settings->remove("");
-    for(int i = 0; i < ui->treeWidget->topLevelItemCount(); ++i)
+
+    const int nItems = ui->treeWidget->topLevelItemCount();
+    for(int i = 0; i < nItems; ++i)
     {
         QTreeWidgetItem *item = ui->treeWidget->topLevelItem(i);
+        const QString key = item->text(0);
+        const QString value = item->text(1);
+
+        if (oldSettings.value(key) != value)
+            doRestart = true;
+
         m_settings->setValue(item->text(0), item->text(1));
     }
     m_settings->endGroup();
+
+    if (oldSettings.size() != nItems)
+        doRestart = true;
+
+    if (doRestart)
+        emit needRestart();
 }
 
 void EnvironmentPage::addButton_clicked()
@@ -89,29 +114,27 @@ void EnvironmentPage::addButton_clicked()
     item->setFlags(item->flags() | Qt::ItemIsEditable);
     ui->treeWidget->addTopLevelItem(item);
     ui->treeWidget->setCurrentItem(item);
-    emit needRestart();
 }
 
 void EnvironmentPage::deleteButton_clicked()
 {
-    foreach (QTreeWidgetItem* item, ui->treeWidget->selectedItems())
+    const auto items = ui->treeWidget->selectedItems();
+    for (QTreeWidgetItem* item : items)
     {
         emit envVarChanged(item->text(0), "");
         delete item;
     }
-    emit needRestart();
 }
 
 void EnvironmentPage::itemChanged(QTreeWidgetItem *item, int column)
 {
     Q_UNUSED(column);
     emit envVarChanged(item->text(0), item->text(1));
-    emit needRestart();
 }
 
 void EnvironmentPage::updateItem(const QString& var, const QString& val)
 {
-    QList<QTreeWidgetItem*> itemList = ui->treeWidget->findItems(var, Qt::MatchExactly);
+    const QList<QTreeWidgetItem*> itemList = ui->treeWidget->findItems(var, Qt::MatchExactly);
     if (itemList.isEmpty())
     {
         QTreeWidgetItem *item = new QTreeWidgetItem(ui->treeWidget, QStringList() << var << val);
@@ -120,12 +143,11 @@ void EnvironmentPage::updateItem(const QString& var, const QString& val)
         return;
     }
 
-    foreach (QTreeWidgetItem* item, itemList)
+    for (QTreeWidgetItem* item : itemList)
     {
         if (!val.isEmpty())
             item->setText(1, val);
         else
             delete item;
     }
-    emit needRestart();
 }
