@@ -2,7 +2,7 @@
  * (c)LGPL2+
  *
  * LXQt - a lightweight, Qt based, desktop toolset
- * http://razor-qt.org, http://lxde.org/
+ * https://lxqt.org/
  *
  * Copyright: 2010-2011 LXQt team
  * Authors:
@@ -103,7 +103,7 @@ void SessionConfigWindow::handleCfgComboBox(QComboBox * cb,
                                            )
 {
     QStringList realValues;
-    foreach (const QString &s, availableValues)
+    for (const QString &s : availableValues)
     {
         if (findProgram(s))
             realValues << s;
