@@ -2,7 +2,7 @@
  * (c)LGPL2+
  *
  * LXQt - a lightweight, Qt based, desktop toolset
- * http://razor-qt.org, http://lxde.org/
+ * https://lxqt.org/
  *
  * Copyright: 2010-2011 LXQt team
  * Authors:
@@ -90,7 +90,7 @@ void LXQtModuleManager::startup(LXQt::Settings& s)
     paths << XdgDirs::dataHome(false);
     paths << XdgDirs::dataDirs();
 
-    foreach(const QString &path, paths)
+    for(const QString &path : qAsConst(paths))
     {
         QFileInfo fi(QString("%1/lxqt/themes").arg(path));
         if (fi.exists())
@@ -103,9 +103,9 @@ void LXQtModuleManager::startup(LXQt::Settings& s)
 void LXQtModuleManager::startAutostartApps()
 {
     // XDG autostart
-    XdgDesktopFileList fileList = XdgAutoStart::desktopFileList();
-    QList<XdgDesktopFile*> trayApps;
-    for (XdgDesktopFileList::iterator i = fileList.begin(); i != fileList.end(); ++i)
+    const XdgDesktopFileList fileList = XdgAutoStart::desktopFileList();
+    QList<const XdgDesktopFile*> trayApps;
+    for (XdgDesktopFileList::const_iterator i = fileList.constBegin(); i != fileList.constEnd(); ++i)
     {
         if (i->value("X-LXQt-Need-Tray", false).toBool())
             trayApps.append(&(*i));
@@ -128,7 +128,7 @@ void LXQtModuleManager::startAutostartApps()
             waitLoop.exec();
             mWaitLoop = NULL;
         }
-        foreach (XdgDesktopFile* f, trayApps)
+        for (const XdgDesktopFile* const f : qAsConst(trayApps))
         {
             qCDebug(SESSION) << "start tray app" << f->fileName();
             startProcess(*f);
@@ -139,7 +139,7 @@ void LXQtModuleManager::startAutostartApps()
 void LXQtModuleManager::themeFolderChanged(const QString& /*path*/)
 {
     QString newTheme;
-    if (!QFileInfo(mCurrentThemePath).exists())
+    if (!QFileInfo::exists(mCurrentThemePath))
     {
         const QList<LXQtTheme> &allThemes = lxqtTheme.allThemes();
         if (!allThemes.isEmpty())
@@ -251,7 +251,8 @@ void LXQtModuleManager::startProcess(const QString& name)
 {
     if (!mNameMap.contains(name))
     {
-        foreach (const XdgDesktopFile& file, XdgAutoStart::desktopFileList(false))
+        const auto files = XdgAutoStart::desktopFileList(false);
+        for (const XdgDesktopFile& file : files)
         {
             if (QFileInfo(file.fileName()).fileName() == name)
             {
